@@ -3,9 +3,14 @@ from .exchange_calendar_asx import ASXExchangeCalendar
 from .exchange_calendar_bmf import BMFExchangeCalendar
 from .exchange_calendar_cboe import CFEExchangeCalendar
 from .exchange_calendar_cme import \
-    CMEAgricultureExchangeCalendar, \
     CMEEquityExchangeCalendar, \
     CMEBondExchangeCalendar
+from .exchange_calendar_cme_globex_base import CMEGlobexBaseExchangeCalendar
+from .exchange_calendar_cme_globex_agriculture import CMEGlobexAgricultureExchangeCalendar
+from .exchange_calendar_cme_globex_fx import CMEGlobexFXExchangeCalendar
+from .exchange_calendar_cme_globex_energy_and_metals import CMEGlobexEnergyAndMetalsExchangeCalendar
+from .exchange_calendar_cme_globex_equities import CMEGlobexEquitiesExchangeCalendar
+from .exchange_calendar_cme_globex_fixed_income import CMEGlobexFixedIncomeCalendar
 from .exchange_calendar_eurex import EUREXExchangeCalendar
 from .exchange_calendar_hkex import HKEXExchangeCalendar
 from .exchange_calendar_ice import ICEExchangeCalendar
